@@ -39,13 +39,31 @@ batchdownloader::batchdownloader( const Context& ctx ) :
 	m_tableWidgetBDList( *m_ui.TableWidgetBatchDownloaderList,0,m_ctx.mainWidget().font() ),
 	m_defaultVideoThumbnail( m_settings.defaultVideoThumbnailIcon( settings::tabName::batch ) ),
 	m_downloadingComments( tr( "Downloading comments" ).toUtf8() ),
-	m_startAutoDownload( m_settings.autoDownloadWhenAddedInBatchDownloader() ),
 	m_subtitlesTimer( m_tableWidgetBDList )
 {
 	qRegisterMetaType< ItemEntry >() ;
+	qRegisterMetaType< ItemEntries >() ;
 
 	this->setShowMetaData( m_settings.showMetaDataInBatchDownloader() ) ;
 
+	connect( this,
+		&batchdownloader::showMetaDataSignal,
+		this,
+		&batchdownloader::showMetaDataSlot,
+		Qt::QueuedConnection ) ;
+
+	connect( this,
+		 &batchdownloader::downloadAddItemsSignal,
+		 this,
+		 &batchdownloader::downloadAddItems,
+		 Qt::QueuedConnection ) ;
+
+	connect( this,
+		 &batchdownloader::networkDataSignal,
+		 this,
+		 &batchdownloader::networkData,
+		 Qt::QueuedConnection ) ;
+
 	connect( this,&batchdownloader::reportFStatus,
 		 this,
 		 &batchdownloader::reportFinishedStatus,
@@ -226,20 +244,13 @@ batchdownloader::batchdownloader( const Context& ctx ) :
 
 		auto m = utility::clipboardText() ;
 
-		if( m.startsWith( "http" ) || m.startsWith( "yt-dlp " ) ){
+		if( m.startsWith( "http" ) ){
 
-			auto ss = m_showMetaData ;
+			this->addToList( m,{ this->showMetaData(),this->autoDownloadWhenAdded() } ) ;
 
-			if( ss && m.startsWith( "yt-dlp " ) ){
+		}else if( m.startsWith( "yt-dlp " ) ){
 
-				ss = false ;
-			}
-
-			batchdownloader::tmpChangeOptions tmp( *this,m_startAutoDownload,ss ) ;
-
-			tmp.set() ;
-
-			this->addToList( m ) ;
+			this->addToList( m,{ false,this->autoDownloadWhenAdded() } ) ;
 		}
 	} ) ;
 
@@ -296,7 +307,12 @@ batchdownloader::batchdownloader( const Context& ctx ) :
 
 			m_ui.lineEditBDUrl->clear() ;
 
-			this->addToList( m ) ;
+			if( m.startsWith( "yt-dlp " ) ){
+
+				this->addToList( m,{ false,this->autoDownloadWhenAdded() } ) ;
+			}else{
+				this->addToList( m,{ this->showMetaData(),this->autoDownloadWhenAdded() } ) ;
+			}
 		}
 	} ) ;
 }
@@ -633,22 +649,14 @@ void batchdownloader::gotEvent( const QJsonObject& jsonArgs )
 
 		auto autoDownload = jsonArgs.value( "-a" ).toBool() ;
 
-		bool showMetaData ;
-
 		auto v = jsonArgs.value( "-e" ) ;
 
 		if( v.isUndefined() ){
 
-			showMetaData = m_showMetaData ;
+			this->addToList( url,{ this->showMetaData(),autoDownload } ) ;
 		}else{
-			showMetaData = v.toBool() ;
+			this->addToList( url,{ this->showMetaData() ? v.toBool() : false,autoDownload } ) ;
 		}
-
-		batchdownloader::tmpChangeOptions tmp( *this,autoDownload,showMetaData ) ;
-
-		tmp.set() ;
-
-		this->addToList( url ) ;
 	}
 }
 
@@ -669,94 +677,123 @@ void batchdownloader::updateEnginesList( const QStringList& e )
 	utility::setUpdefaultEngine( comboBox,m,m_settings,s ) ;
 }
 
-void batchdownloader::downloadAddItems( const engines::engine& engine,Items list )
+void batchdownloader::downloadAddItems( ItemEntries s )
 {
-	auto row = this->addItemUi( m_defaultVideoThumbnail,-1,false,list.first().url ) ;
+	if( s.hasNext() ){
 
-	this->setDownloadingOptions( row,m_table ) ;
+		auto e = s.next() ;
 
-	const auto& ee = m_table.entryAt( row ) ;
+		auto row = this->addItemUi( m_defaultVideoThumbnail,-1,false,e.url ) ;
 
-	const auto& eng = m_ctx.Engines().getEngineByName( ee.engineName ) ;
+		this->setDownloadingOptions( row,m_table ) ;
 
-	if( eng ){
+		const auto& ee = m_table.entryAt( row ) ;
 
-		this->downloadSingle( eng.value(),row ) ;
-	}else{
-		this->downloadSingle( engine,row ) ;
-	}
-}
+		const auto& eng = m_ctx.Engines().getEngineByName( ee.engineName ) ;
 
-void batchdownloader::showThumbnail( const engines::engine& engine,
-				     Items list,
-				     bool autoDownload,
-				     bool showThumbnails )
-{
-	if( list.isEmpty() ){
+		if( eng ){
 
-		return ;
-	}
-
-	if( !m_initDone ){
-
-		this->addItemUiSlot( { engine,list.move() } ) ;
-
-	}else  if( m_startAutoDownload && list.hasOneEntry() ){
-
-		this->downloadAddItems( engine,list.move() ) ;
-
-	}else if( autoDownload && !showThumbnails && list.hasOneEntry() ){
-
-		this->downloadAddItems( engine,list.move() ) ;
-
-	}else if( m_showMetaData && engine.canShowMetaData() ){
-
-		if( m_recursiveDownloading ){
-
-			this->addItemUiSlot( { engine,list.move() } ) ;
+			this->downloadRecursively( eng.value(),row ) ;
 		}else{
-			auto& c = m_ctx.TabManager().Configure() ;
-
-			auto& engines = m_ctx.Engines() ;
-
-			for( const auto& it : list ){
-
-				this->showThumbnail( engine,engines,it,c,autoDownload ) ;
-			}
+			this->downloadRecursively( s.engine(),row ) ;
 		}
-	}else{
-		this->addItemUiSlot( { engine,list.move() } ) ;
+
+		emit this->downloadAddItemsSignal( s ) ;
+
+	}else if( s.hasMore() ){
+
+		s.setMore() ;
+
+		this->addItemUiSlot( s ) ;
 	}
 }
 
-void batchdownloader::showThumbnail( const engines::engine& engine,
-				    const engines& engs,
-				    const Items::entry& it,
-				    configure& c,
-				    bool autoDownload )
+void batchdownloader::downloadOrShowThumbnail( ItemEntries entries,const downloadOpts& opts )
 {
-	auto s = c.getEngineNameFromUrlManager( it.url ) ;
+	if( entries.hasMore() ){
 
-	if( s.isEmpty() ){
+		if( !m_initDone ){
 
-		this->getMetaData( it,engine,autoDownload ) ;
-	}else{
-		auto ss = engs.getEngineByName( s ) ;
+			this->addItemUiSlot( entries.move() ) ;
 
-		if( ss ){
+		}else if( opts.autoDownload() ){
 
-			if( ss->canShowMetaData() ){
+			this->downloadAddItems( entries.move() ) ;
 
-				this->getMetaData( it,ss.value(),autoDownload ) ;
+		}else if( opts.showMetaData() && entries.engine().canShowMetaData() ){
+
+			if( m_table.totalRunningRecursively() > 0 ){
+
+				this->addItemUiSlot( entries.move() ) ;
 			}else{
-				this->addItemUiSlot( { ss.value(),it } ) ;
+				this->showMetaDataSlot( entries.move() ) ;
 			}
 		}else{
-			this->addItemUiSlot( { engine,it } ) ;
+			this->addItemUiSlot( entries.move() ) ;
 		}
 	}
 }
 
+void batchdownloader::showMetaDataSlot( ItemEntries e )
+{
+	if( e.hasNext() ){
+
+		auto m = e.next() ;
+
+		auto& c = m_ctx.TabManager().Configure() ;
+
+		auto s = c.getEngineNameFromUrlManager( m.url ) ;
+
+		if( s.isEmpty() ){
+
+			this->getMetaData( e.engine(),m ) ;
+		}else{
+			class meaw
+			{
+			public:
+				meaw( const QString& engineName,
+				      batchdownloader& parent,
+				      const Context& ctx,
+				      const engines::engine& engine,
+				      const Items::entry& entry ) :
+				      m_parent( parent ),m_entry( entry )
+				{
+					auto ss = ctx.Engines().getEngineByName( engineName ) ;
+
+					if( ss ){
+
+						this->exec( ss.value() ) ;
+					}else{
+						this->exec( engine ) ;
+					}
+				}
+			private:
+				void exec( const engines::engine& engine )
+				{
+					if( engine.canShowMetaData() ){
+
+						m_parent.getMetaData( engine,m_entry ) ;
+					}else{
+						m_parent.addItemToUi( engine,m_entry ) ;
+					}
+				}
+				batchdownloader& m_parent ;
+				const Items::entry& m_entry ;
+			} ;
+
+			meaw( s,*this,m_ctx,e.engine(),m ) ;
+		}
+
+		emit this->showMetaDataSignal( e ) ;
+
+	}else if( e.hasMore() ){
+
+		e.setMore() ;
+
+		this->addItemUiSlot( e ) ;
+	}
+}
+
 void batchdownloader::setThumbnail( const std::vector< QByteArray >& fileNames,
 				   const engines::engine& engine,
 				   int row )
@@ -774,6 +811,10 @@ void batchdownloader::setThumbnail( const std::vector< QByteArray >& fileNames,
 		{
 			m_filePath = e ;
 		}
+		bool invalidEntry( const QByteArray& e ) const
+		{
+			return utility::fileIsInvalidForGettingThumbnail( e ) ;
+		}
 		QPixmap bg()
 		{
 			QFile f( m_filePath ) ;
@@ -817,9 +858,7 @@ void batchdownloader::setThumbnail( const std::vector< QByteArray >& fileNames,
 	utility::setThumbNail( fileNames,downloadFolder,meaw( *this,row ) ) ;
 }
 
-void batchdownloader::getMetaData( const Items::entry& it,
-				   const engines::engine& eng,
-				   bool autoDownload )
+void batchdownloader::getMetaData( const engines::engine& eng,const Items::entry& it )
 {
 	tableWidget::entry entry( it ) ;
 
@@ -857,7 +896,7 @@ void batchdownloader::getMetaData( const Items::entry& it,
 
 	m_table.selectLast() ;
 
-	this->showThumbnail( eng,row,it.url,autoDownload ) ;
+	this->showThumbnail( eng,row,it.url ) ;
 }
 
 void batchdownloader::setDefaultEngineAndOptions( Items::entry& s )
@@ -920,49 +959,54 @@ void batchdownloader::setDefaultEngineAndOptions( Items::entry& s )
 	s.uiText = mm.join( "\n" ) ;
 }
 
-void batchdownloader::addItemUiSlot( ItemEntry m )
+void batchdownloader::addItemToUi( const engines::engine& engine,Items::entry s )
+{
+	auto row = this->addItemUi( m_defaultVideoThumbnail,-1,false,s.toJsonDoc() ) ;
+
+	auto ss = m_ctx.TabManager().Configure().getEngineNameFromUrlManager( s.url ) ;
+
+	if( !ss.isEmpty() ){
+
+		s.engineName = ss ;
+	}
+
+	if( s.engineName.isEmpty() ){
+
+		this->setDefaultEngineAndOptions( s ) ;
+	}
+
+	m_table.setUiText( s.uiText,row ) ;
+	m_table.setEngineName( s.engineName,row ) ;
+	m_table.setExtraDownloadOptions( s.downloadExtraOptions,row ) ;
+
+	if( s.downloadOptions.isEmpty() ){
+
+		m_ctx.TabManager().Configure().setDownloadOptions( row,m_table ) ;
+	}else{
+		m_table.setDownloadingOptions( s.downloadOptions,row ) ;
+	}
+
+	auto e = static_cast< int >( m_settings.maxConcurrentDownloads() ) ;
+
+	auto m = m_table.totalRunningRecursively() ;
+
+	if( m > 0 && m < e ){
+
+		this->downloadRecursively( engine,row ) ;
+	}
+}
+
+void batchdownloader::addItemUiSlot( ItemEntries m )
 {
 	if( m.hasNext() ){
 
-		auto s = m.next() ;
+		this->addItemToUi( m.engine(),m.next() ) ;
 
-		auto row = this->addItemUi( m_defaultVideoThumbnail,-1,false,s.toJsonDoc() ) ;
+		emit this->addItemUiSignal( m ) ;
 
-		auto ss = m_ctx.TabManager().Configure().getEngineNameFromUrlManager( s.url ) ;
+	}else if( m.hasMore() ){
 
-		if( !ss.isEmpty() ){
-
-			s.engineName = ss ;
-		}
-
-		if( s.engineName.isEmpty() ){
-
-			this->setDefaultEngineAndOptions( s ) ;
-		}
-
-		m_table.setUiText( s.uiText,row ) ;
-		m_table.setEngineName( s.engineName,row ) ;
-		m_table.setExtraDownloadOptions( s.downloadExtraOptions,row ) ;
-
-		if( s.downloadOptions.isEmpty() ){
-
-			m_ctx.TabManager().Configure().setDownloadOptions( row,m_table ) ;
-		}else{
-			m_table.setDownloadingOptions( s.downloadOptions,row ) ;
-		}
-
-		auto e = static_cast< int >( m_settings.maxConcurrentDownloads() ) ;
-
-		if( m_recursiveDownloading > 0 && m_recursiveDownloading < e ){
-
-			const auto& eng = m.engine() ;
-
-			const auto& engines = m_ctx.Engines() ;
-
-			const auto& engine = utility::resolveEngine( m_table,eng,engines,row ) ;
-
-			this->downloadRecursively( engine,row ) ;
-		}
+		m.setMore() ;
 
 		emit this->addItemUiSignal( m ) ;
 	}
@@ -1239,15 +1283,16 @@ void batchdownloader::setVisibleWidgetOverMainTable( bool e )
 
 void batchdownloader::renameFile( int row )
 {
-	const auto& df = m_ctx.Settings().downloadFolder() ;
 	const auto& fn = m_table.entryAt( row ).fileNames ;
-	const auto& nn = m_ui.plainTextEditBD->toPlainText() ;
 
 	if( fn.size() ){
 
+		auto nn = m_ui.plainTextEditBD->toPlainText() ;
+		auto df = m_ctx.Settings().downloadFolder() ;
+
 		auto& item = m_table.item( row,m_table.startPosition() ) ;
 
-		auto m = utility::rename( item,df,nn,fn[ 0 ] ) ;
+		auto m = utility::rename( m_ctx,item,df,nn,fn[ 0 ] ) ;
 
 		if( !m.isEmpty() ){
 
@@ -1634,142 +1679,6 @@ void batchdownloader::showBDFrame( batchdownloader::listType m )
 	m_ui.pbCancelBatchDownloder->setFocus() ;
 }
 
-template< typename Function >
-static void _dataFromFile( Items& items,
-			   const Context& ctx,
-			   const QJsonArray& array,
-			   const QString& urlKey,
-			   const QString& uploadDate,
-			   const Function& converter )
-{
-	for( const auto& it : array ){
-
-		auto obj = it.toObject() ;
-
-		if( obj.isEmpty() ){
-
-			continue ;
-		}
-
-		auto url = obj.value( urlKey ).toString() ;
-
-		obj.insert( "webpage_url",url ) ;
-
-		auto d = utility::stringConstants::duration() + " " ;
-		auto u = utility::stringConstants::uploadDate() + " " ;
-
-		auto title    = obj.value( "title" ).toString() ;
-		auto duration = converter( obj.value( "duration" ) ) ;
-		auto date     = obj.value( uploadDate ).toString() ;
-
-		auto engineName   = obj.value( "engineName" ).toString() ;
-		auto downloadOpts = obj.value( "downloadOptions" ).toString() ;
-		auto downloadExtOpts = obj.value( "downloadExtraOptions" ).toString() ;
-
-		if( !duration.isEmpty() ){
-
-			duration = d + duration ;
-		}
-
-		if( !date.isEmpty() ){
-
-			date = u + date ;
-		}
-
-		QString durationAndDate ;
-
-		if( !duration.isEmpty() && !date.isEmpty() ){
-
-			durationAndDate = duration + ", " + date ;
-
-		}else if( duration.isEmpty() ){
-
-			if( date.isEmpty() ){
-
-			}else{
-				durationAndDate = date ;
-			}
-
-		}else if( date.isEmpty() ){
-
-			if( duration.isEmpty() ){
-
-			}else{
-				durationAndDate = duration ;
-			}
-		}
-
-		QString opts ;
-
-		if( !engineName.isEmpty() ){
-
-			opts = utility::stringConstants::engineName() + engineName ;
-		}
-
-		if( !downloadOpts.isEmpty() ){
-
-			auto& cc = ctx.TabManager().Configure() ;
-			downloadOpts = cc.optionsTranslated( downloadOpts ) ;
-
-			auto mm = utility::stringConstants::downloadOptions() ;
-			auto dopts = mm + ": " + downloadOpts ;
-
-			if( opts.isEmpty() ){
-
-				opts = dopts ;
-			}else{
-				opts += "\n" + dopts ;
-			}
-		}
-
-		if( !downloadExtOpts.isEmpty() ){
-
-			auto mm = utility::stringConstants::downloadExtendedOptions() ;
-
-			auto dopts = mm + ": " + downloadExtOpts ;
-
-			if( opts.isEmpty() ){
-
-				opts = dopts ;
-			}else{
-				opts += "\n" + dopts ;
-			}
-		}
-
-		auto _set_title = []( const QString& e ){
-
-			if( e.isEmpty() ){
-
-				return QString() ;
-			}else{
-				return "\n" + e ;
-			}
-		} ;
-
-		if( opts.isEmpty() ){
-
-			if( durationAndDate.isEmpty() ){
-
-				obj.insert( "uiText",title ) ;
-			}else{
-				auto txt = durationAndDate + _set_title( title ) ;
-				obj.insert( "uiText",txt ) ;
-			}
-		}else{
-			if( durationAndDate.isEmpty() ){
-
-				obj.insert( "uiText",opts + _set_title( title ) ) ;
-			}else{
-				auto txt = opts + "\n" + durationAndDate + _set_title( title ) ;
-
-				obj.insert( "uiText",txt ) ;
-			}
-		}
-
-		items.add( std::move( obj ) ) ;
-	}
-}
-
 void batchdownloader::parseDataFromFile( Items& items,const QByteArray& data )
 {
 	QJsonParseError err ;
@@ -1782,20 +1691,22 @@ void batchdownloader::parseDataFromFile( Items& items,const QByteArray& data )
 	}
 }
 
-void batchdownloader::parseItems( Items items )
+void batchdownloader::parseItems( Items items,const batchdownloader::downloadOpts& opts )
 {
-	const auto& engine = this->defaultEngine() ;
+	const auto& engine    = this->defaultEngine() ;
+	auto currentlyRunning = m_table.numberCurrentlyRunning() ;
+	auto maxRunning       = static_cast< int >( m_settings.maxConcurrentDownloads() ) ;
+	auto size             = static_cast< int >( items.size() ) ;
+	auto availableSlots   = maxRunning - currentlyRunning ;
 
-	if( items.size() <= m_settings.maxConcurrentDownloads() ){
+	Items itms ;
 
-		auto m = m_settings.autoDownloadWhenAddedInBatchDownloader() ;
-		this->showThumbnail( engine,items.move(),m ) ;
-	}else{
-		auto m = m_showMetaData ;
-		m_showMetaData = false ;
-		this->showThumbnail( engine,items.move() ) ;
-		m_showMetaData = m ;
+	for( int i = 0 ; i < size && i < availableSlots ; i++ ){
+
+		itms.add( items.takeFirst() ) ;
 	}
+
+	this->downloadOrShowThumbnail( { { engine,itms.move() },{ engine,items.move() } },opts ) ;
 }
 
 void batchdownloader::parseDataFromObject( Items& items,const QJsonObject& obj,const QJsonArray& array )
@@ -1813,7 +1724,7 @@ void batchdownloader::parseDataFromObject( Items& items,const QJsonObject& obj,c
 		auto a = "url" ;
 		auto b = "uploadDate" ;
 
-		_dataFromFile( items,m_ctx,array,a,b,function ) ;
+		this->dataFromFile( items,{ array,a,b },function ) ;
 	}else{
 		/*
 		 * File created with yt-dlp
@@ -1831,7 +1742,7 @@ void batchdownloader::parseDataFromObject( Items& items,const QJsonObject& obj,c
 			auto a = "webpage_url" ;
 			auto b = "upload_date" ;
 
-			_dataFromFile( items,m_ctx,array,a,b,function ) ;
+			this->dataFromFile( items,{ array,a,b },function ) ;
 		}
 	}
 }
@@ -1864,14 +1775,10 @@ void batchdownloader::getListFromFile( const QString& e,bool deleteFile )
 				}
 			}
 
-			batchdownloader::tmpChangeOptions opts( *this,false,false ) ;
-
-			opts.set() ;
-
 			if( items.size() ){
 
 				m_ui.tabWidget->setCurrentIndex( 1 ) ;
-				this->parseItems( items.move() ) ;
+				this->parseItems( items.move(),{ false,false } ) ;
 			}
 		}
 	} ) ;
@@ -1996,9 +1903,8 @@ void batchdownloader::updateTitleBar()
 }
 
 void batchdownloader::showThumbnail( const engines::engine& engine,
-				     int index,
-				     const QString& url,
-				     bool autoDownload )
+				    int index,
+				    const QString& url )
 {			
 	class events
 	{
@@ -2006,13 +1912,11 @@ void batchdownloader::showThumbnail( const engines::engine& engine,
 		events( batchdownloader& p,
 			const engines::engine& engine,
 			int index,
-			bool autoDownload,
 			const QString& url,
 			BatchLoggerWrapper< batchdownloader::defaultLogger > logger ) :
 			m_parent( p ),
 			m_engine( engine ),
 			m_index( index ),
-			m_autoDownload( autoDownload ),
 			m_url( url ),
 			m_logger( logger )
 		{
@@ -2044,11 +1948,6 @@ void batchdownloader::showThumbnail( const engines::engine& engine,
 				}
 
 				m_parent.addItem( this->index(),enableAll,m.move() ) ;
-
-				if( m_autoDownload ){
-
-					m_parent.downloadSingle( m_engine,m_index ) ;
-				}
 			}else{
 				m_parent.addItem( this->index(),enableAll,m_url ) ;
 			}
@@ -2091,7 +1990,6 @@ void batchdownloader::showThumbnail( const engines::engine& engine,
 		batchdownloader& m_parent ;
 		const engines::engine& m_engine ;
 		int m_index ;
-		bool m_autoDownload ;
 		QString m_url ;
 		BatchLoggerWrapper< batchdownloader::defaultLogger > m_logger ;
 	} ;
@@ -2134,7 +2032,7 @@ void batchdownloader::showThumbnail( const engines::engine& engine,
 
 	args.append( m_table.url( index ) ) ;
 
-	auto ctx = utility::make_ctx( events( *this,engine,index,autoDownload,url,wrapper ),
+	auto ctx = utility::make_ctx( events( *this,engine,index,url,wrapper ),
 				     wrapper,
 				     m_terminator.setUp(),
 				     QProcess::ProcessChannel::StandardOutput ) ;
@@ -2198,9 +2096,7 @@ int batchdownloader::addItemUi( const QPixmap& pixmap,
 
 void batchdownloader::setShowMetaData( bool e )
 {
-	m_showMetaData = e ;
-
-	if( m_showMetaData ){
+	if( e ){
 
 		m_table.get().showColumn( 0 ) ;
 
@@ -2227,6 +2123,140 @@ void batchdownloader::textAlignmentChanged( Qt::LayoutDirection m )
 	utility::alignText( m,a,b,c ) ;
 }
 
+void batchdownloader::dataFromFile( Items& items,
+				   const batchdownloader::dataFromFileOpts& dFileopts,
+				   QJsonObject& obj,
+				   const QString& drion )
+{
+	auto url = obj.value( dFileopts.urlKey ).toString() ;
+
+	obj.insert( "webpage_url",url ) ;
+
+	auto d = utility::stringConstants::duration() + " " ;
+	auto u = utility::stringConstants::uploadDate() + " " ;
+
+	auto title    = obj.value( "title" ).toString() ;
+	auto date     = obj.value( dFileopts.uploadDate ).toString() ;
+
+	auto engineName      = obj.value( "engineName" ).toString() ;
+	auto downloadOpts    = obj.value( "downloadOptions" ).toString() ;
+	auto downloadExtOpts = obj.value( "downloadExtraOptions" ).toString() ;
+
+	auto duration = drion ;
+
+	if( !duration.isEmpty() ){
+
+		duration = d + duration ;
+	}
+
+	if( !date.isEmpty() ){
+
+		date = u + date ;
+	}
+
+	QString durationAndDate ;
+
+	if( !duration.isEmpty() && !date.isEmpty() ){
+
+		durationAndDate = duration + ", " + date ;
+
+	}else if( duration.isEmpty() ){
+
+		if( date.isEmpty() ){
+
+		}else{
+			durationAndDate = date ;
+		}
+
+	}else if( date.isEmpty() ){
+
+		if( duration.isEmpty() ){
+
+		}else{
+			durationAndDate = duration ;
+		}
+	}
+
+	QString opts ;
+
+	if( !engineName.isEmpty() ){
+
+		opts = utility::stringConstants::engineName() + engineName ;
+	}
+
+	if( !downloadOpts.isEmpty() ){
+
+		auto& cc = m_ctx.TabManager().Configure() ;
+		downloadOpts = cc.optionsTranslated( downloadOpts ) ;
+
+		auto mm = utility::stringConstants::downloadOptions() ;
+		auto dopts = mm + ": " + downloadOpts ;
+
+		if( opts.isEmpty() ){
+
+			opts = dopts ;
+		}else{
+			opts += "\n" + dopts ;
+		}
+	}
+
+	if( !downloadExtOpts.isEmpty() ){
+
+		auto mm = utility::stringConstants::downloadExtendedOptions() ;
+
+		auto dopts = mm + ": " + downloadExtOpts ;
+
+		if( opts.isEmpty() ){
+
+			opts = dopts ;
+		}else{
+			opts += "\n" + dopts ;
+		}
+	}
+
+	auto _set_title = []( const QString& e ){
+
+		if( e.isEmpty() ){
+
+			return QString() ;
+		}else{
+			return "\n" + e ;
+		}
+	} ;
+
+	if( opts.isEmpty() ){
+
+		if( durationAndDate.isEmpty() ){
+
+			obj.insert( "uiText",title ) ;
+		}else{
+			auto txt = durationAndDate + _set_title( title ) ;
+			obj.insert( "uiText",txt ) ;
+		}
+	}else{
+		if( durationAndDate.isEmpty() ){
+
+			obj.insert( "uiText",opts + _set_title( title ) ) ;
+		}else{
+			auto txt = opts + "\n" + durationAndDate + _set_title( title ) ;
+
+			obj.insert( "uiText",txt ) ;
+		}
+	}
+
+	items.add( std::move( obj ) ) ;
+}
+
+bool batchdownloader::showMetaData()
+{
+	return m_settings.showMetaDataInBatchDownloader() ;
+}
+
+bool batchdownloader::autoDownloadWhenAdded()
+{
+	return m_settings.autoDownloadWhenAddedInBatchDownloader() ;
+}
+
 void batchdownloader::clipboardData( const QString& url,bool s )
 {
 	if( s ){
@@ -2245,19 +2275,12 @@ void batchdownloader::addClipboardSlot( QString url )
 
 			m_ui.tabWidget->setCurrentIndex( 1 ) ;
 
-			auto showMetaData = m_showMetaData ;
+			if( url.startsWith( "yt-dlp " ) ){
 
-			if( showMetaData && url.startsWith( "yt-dlp " ) ){
-
-				showMetaData = false ;
+				this->addToList( url,{ false,this->autoDownloadWhenAdded() } ) ;
+			}else{
+				this->addToList( url,{ this->showMetaData(),this->autoDownloadWhenAdded() } ) ;
 			}
-
-			auto m = m_startAutoDownload ;
-			batchdownloader::tmpChangeOptions tmp( *this,m,showMetaData ) ;
-
-			tmp.set() ;
-
-			this->addToList( url ) ;
 		}
 	}
 }
@@ -2580,7 +2603,7 @@ void batchdownloader::addItemUi( int index,bool enableAll,const utility::MediaEn
 	this->addItemUi( m_defaultVideoThumbnail,index,enableAll,media ) ;
 }
 
-void batchdownloader::networkData( const utility::networkReply& m )
+void batchdownloader::networkData( utility::networkReply m )
 {
 	if( networkAccess::hasNetworkSupport() ){
 
@@ -2622,109 +2645,133 @@ void batchdownloader::addItem( int index,bool enableAll,const utility::MediaEntr
 	if( media.thumbnailUrl().isEmpty() ){
 
 		this->addItemUi( index,enableAll,media ) ;
+
+	}else if( this->showMetaData() && networkAccess::hasNetworkSupport() ){
+
+		auto u = media.thumbnailUrl() ;
+
+		networkCtx n{ media,index } ;
+
+		auto m = &batchdownloader::networkResult ;
+
+		m_ctx.network().get( u,n.move(),this,m ) ;
 	}else{
-		if( m_showMetaData && networkAccess::hasNetworkSupport() ){
-
-			auto u = media.thumbnailUrl() ;
-
-			networkCtx n{ media,index } ;
-
-			auto m = &batchdownloader::networkResult ;
-
-			m_ctx.network().get( u,n.move(),this,m ) ;
-		}else{
-			this->addItemUi( index,enableAll,media ) ;
-		}
+		this->addItemUi( index,enableAll,media ) ;
 	}
 }
 
 void batchdownloader::networkResult( networkCtx d,const utils::network::reply& reply )
 {
-	auto m = &batchdownloader::networkData ;
-	utility::networkReply( this,m,m_ctx,reply,nullptr,d.index,d.media.move() ) ;
+	emit this->networkDataSignal( { m_ctx,reply,d.index,d.media.move() } ) ;
 }
 
-void batchdownloader::addToList( const QString& u )
+void batchdownloader::addToList( const QString& u,const batchdownloader::downloadOpts& opts )
 {
-	const auto& ee = this->defaultEngine() ;
+	class meaw
+	{
+	public:
+		meaw( batchdownloader& p,const QString& url,const batchdownloader::downloadOpts& opts ) :
+			m_parent( p ),
+			m_url( url ),
+			m_opts( opts )
+		{
+		}
+		void operator()()
+		{
+			Items items ;
 
-	ee.updateVersionInfo( m_ctx,[ this,u ](){
+			for( const auto& it : util::split( m_url,'\n',true ) ){
 
-		Items items ;
+				if( it.startsWith( "#" ) ){
 
-		for( const auto& it : util::split( u,'\n',true ) ){
+					continue ;
 
-			if( it.startsWith( "#" ) ){
+				}else if( it.startsWith( "yt-dlp" ) ){
 
-				continue ;
-
-			}else if( it.startsWith( "yt-dlp" ) ){
-
-				/*
-				 * Entry looks like yt-dlp ${YTDLP_OPTIONS} URL
-				 * Stream detector has ability to create such entries
-				 * https://github.com/54ac/stream-detector
-				 */
-
-				auto m = util::split( it,' ',true ) ;
-
-				QJsonObject obj ;
-
-				auto url = m.takeLast() ;
-
-				if( url.startsWith( "\"" ) ){
-
-					url.remove( 0,1 ) ;
+					this->parseYtdlp( it,items ) ;
+				}else{
+					this->parseUrl( it,items ) ;
 				}
+			}
 
-				if( url.endsWith( "\"" ) ){
+			m_parent.parseItems( items.move(),m_opts ) ;
+		}
+	private:
+		void parseUrl( const QString& it,Items& items )
+		{
+			auto url = it ;
 
-					url.remove( url.size() - 1,1 ) ;
-				}
+			url.replace( "\r","" ) ;
 
-				url.replace( "\r","" ) ;
+			for( const auto& xt : util::split( url,' ',true ) ){
 
-				obj.insert( "engineName",m.takeFirst() ) ;
-				obj.insert( "downloadOptions",m.join( " " ) ) ;
-				obj.insert( "url",url ) ;
-				obj.insert( "uiText",url ) ;
+				auto row = m_parent.m_table.rowWithUrl( xt ) ;
 
-				QJsonArray arr ;
+				if( row == -1 ){
 
-				arr.append( obj ) ;
-
-				this->parseDataFromObject( items,QJsonObject(),arr ) ;
-			}else{
-				auto url = it ;
-
-				url.replace( "\r","" ) ;
-
-				for( const auto& xt : util::split( url,' ',true ) ){
-
-					auto row = m_table.rowWithUrl( xt ) ;
-
-					if( row == -1 ){
-
-						items.add( xt ) ;
-					}else{
-						m_table.selectRow( row ) ;
-					}
+					items.add( xt ) ;
+				}else{
+					m_parent.m_table.selectRow( row ) ;
 				}
 			}
 		}
+		void parseYtdlp( const QString& it,Items& items )
+		{
+			/*
+			 * Entry looks like yt-dlp ${YTDLP_OPTIONS} URL
+			 * Stream detector has ability to create such entries
+			 * https://github.com/54ac/stream-detector
+			 */
 
-		this->parseItems( items.move() ) ;
-	} ) ;
+			auto m = util::split( it,' ',true ) ;
+
+			if( m.size() < 3 ){
+
+				return ;
+			}
+
+			QJsonObject obj ;
+
+			auto url = m.takeLast() ;
+
+			if( url.startsWith( "\"" ) ){
+
+				url.remove( 0,1 ) ;
+			}
+
+			if( url.endsWith( "\"" ) ){
+
+				url.remove( url.size() - 1,1 ) ;
+			}
+
+			url.replace( "\r","" ) ;
+
+			obj.insert( "engineName",m.takeFirst() ) ;
+			obj.insert( "downloadOptions",m.join( " " ) ) ;
+			obj.insert( "url",url ) ;
+			obj.insert( "uiText",url ) ;
+
+			QJsonArray arr ;
+
+			arr.append( obj ) ;
+
+			m_parent.parseDataFromObject( items,QJsonObject(),arr ) ;
+		}
+		batchdownloader& m_parent ;
+		QString m_url ;
+		batchdownloader::downloadOpts m_opts ;
+	} ;
+
+	this->defaultEngine().updateVersionInfo( m_ctx,meaw( *this,u,opts ) ) ;
 }
 
 void batchdownloader::download( const engines::engine& engine )
 {
-	m_topDownloadingIndex = 0 ;
-	m_recursiveDownloading = 0 ;
+	auto a = m_ui.cbEngineTypeBD->currentText() ;
+	auto b = m_ui.lineEditBDUrlOptions->text() ;
+	auto c = settings::tabName::batch ;
 
-	m_settings.setLastUsedOption( m_ui.cbEngineTypeBD->currentText(),
-				     m_ui.lineEditBDUrlOptions->text(),
-				     settings::tabName::batch ) ;
+	m_settings.setLastUsedOption( a,b,c ) ;
 
 	m_ctx.TabManager().basicDownloader().hideTableList() ;
 
@@ -2737,11 +2784,9 @@ void batchdownloader::download( const engines::engine& engine )
 		}
 		void operator()()
 		{
-			auto& t = m_parent.m_table ;
-
 			std::vector< int > v ;
 
-			for( int s = 0 ; s < t.rowCount() ; s++ ){
+			for( int s = 0 ; s < m_parent.m_table.rowCount() ; s++ ){
 
 				if( !m_parent.m_table.finishedWithSuccess( s ) ){
 
@@ -2855,10 +2900,9 @@ void batchdownloader::downloadSingle( const engines::engine& eng,int row )
 		}
 		void whenDone( const engines::ProcessExitState& st,const std::vector< QByteArray >& fileNames )
 		{
-			auto a = m_engine.canShowMetaData() ;
-			auto b = m_parent.m_showMetaData ;
+			auto b = m_parent.showMetaData() ;
 
-			if( fileNames.size() && b && st.success() && a && !m_engine.likeYtDlp() ){
+			if( fileNames.size() && b && st.success() && m_engine.isGalleryDl() ){
 
 				m_parent.setThumbnail( fileNames,m_engine,m_index ) ;
 			}
@@ -2875,7 +2919,7 @@ void batchdownloader::downloadSingle( const engines::engine& eng,int row )
 
 	const auto& engine = utility::resolveEngine( m_table,eng,m_ctx.Engines(),row ) ;
 
-	this->downloadEvent( meaw( *this,engine,row ),engine,row ) ;
+	this->downloadEvent( meaw( *this,engine,row ),engine,row,false ) ;
 }
 
 void batchdownloader::downloadRecursively( const engines::engine& eng,int index )
@@ -2889,18 +2933,12 @@ void batchdownloader::downloadRecursively( const engines::engine& eng,int index
 		}
 		void whenCreated()
 		{
-			m_parent.m_topDownloadingIndex++ ;
-			m_parent.m_recursiveDownloading++ ;
 		}
 		void whenDone( const engines::ProcessExitState& st,const std::vector< QByteArray >& fileNames )
 		{
-			m_parent.m_recursiveDownloading-- ;
-
 			if( st.success() ){
 
-				auto m = m_engine.canShowMetaData() ;
-
-				if( m_parent.m_showMetaData && m && !m_engine.likeYtDlp() ){
+				if( m_parent.showMetaData() && m_engine.isGalleryDl() ){
 
 					if( fileNames.size() ){
 
@@ -2921,23 +2959,11 @@ void batchdownloader::downloadRecursively( const engines::engine& eng,int index
 	private:
 		void startNext()
 		{
-			auto m = m_parent.m_topDownloadingIndex ;
+			auto m = m_parent.m_table.nextAvailableEntryToDownload( m_index + 1 ) ;
 
-			if( m < m_parent.m_table.rowCount() ){
+			if( m != -1 ){
 
-				auto e = m_parent.m_table.runningState( m ) ;
-
-				auto a = reportFinished::finishedStatus::running( e ) ;
-				auto b = reportFinished::finishedStatus::finishedWithSuccess( e ) ;
-
-				if( a || b ){
-
-					m_parent.m_topDownloadingIndex++ ;
-
-					this->startNext() ;
-				}else{
-					m_parent.downloadRecursively( m_engine,m ) ;
-				}
+				m_parent.downloadRecursively( m_engine,m ) ;
 			}
 		}
 		batchdownloader& m_parent ;
@@ -2951,7 +2977,7 @@ void batchdownloader::downloadRecursively( const engines::engine& eng,int index
 
 	m_settings.addOptionsHistory( engine.name(),m,settings::tabName::batch ) ;
 
-	this->downloadEvent( meaw( *this,engine,index ),engine,index ) ;
+	this->downloadEvent( meaw( *this,engine,index ),engine,index,true ) ;
 }
 
 void batchdownloader::addTextToUi( const QByteArray& data,int index )
