@@ -511,8 +511,8 @@ public:
 						const engines::engine& e,
 						bool( *m )( const engines::engine&,const QByteArray& ) ) :
 						m_progress( p ),m_meetCondition( m,e )
-						{
-						}
+					{
+					}
 					const QByteArray& progress()
 					{
 						return m_progress ;
@@ -1198,9 +1198,13 @@ public:
 		{
 			return m_likeYtDlp ;
 		}
+		bool isGalleryDl() const
+		{
+			return this->name() == "gallery-dl" ;
+		}
 		bool canShowMetaData() const
 		{
-			return m_likeYtDlp || this->name() == "gallery-dl" ;
+			return m_likeYtDlp || this->isGalleryDl() ;
 		}
 		bool backendExists() const
 		{
