@@ -58,6 +58,12 @@ playlistdownloader::playlistdownloader( Context& ctx ) :
 
 	this->resetMenu() ;
 
+	connect( this,
+		 &playlistdownloader::networkDataSignal,
+		 this,
+		 &playlistdownloader::networkData,
+		 Qt::QueuedConnection ) ;
+
 	connect( this,
 		 &playlistdownloader::addTextToUiSignal,
 		 this,
@@ -252,8 +258,6 @@ playlistdownloader::playlistdownloader( Context& ctx ) :
 
 		if( !m.isEmpty() ){
 
-			m_autoDownload = false ;
-
 			utility::vector< subscription::entry > ss ;
 
 			if( utils::misc::containsAny( m,'\n',' ' ) ){
@@ -269,7 +273,7 @@ playlistdownloader::playlistdownloader( Context& ctx ) :
 				ss.emplace_back( m ) ;
 			}
 
-			this->getListing( ss.move(),this->defaultEngine() ) ;
+			this->getListing( ss.move(),this->defaultEngine(),false ) ;
 		}
 	} ) ;
 
@@ -654,8 +658,6 @@ void playlistdownloader::customContextMenuRequested()
 
 void playlistdownloader::plSubscription()
 {
-	m_autoDownload = false ;
-
 	QMenu m ;
 
 	auto ee = m_subscription.entries() ;
@@ -700,13 +702,11 @@ void playlistdownloader::plSubscription()
 
 			if( s == "Download All Updated" ){
 
-				m_parent.m_autoDownload = true ;
-
-				m_parent.getListing( m_vector.move(),engine ) ;
+				m_parent.getListing( m_vector.move(),engine,true ) ;
 
 			}else if( s == "Show All Updated" ){
 
-				m_parent.getListing( m_vector.move(),engine ) ;
+				m_parent.getListing( m_vector.move(),engine,false ) ;
 
 			}else if( s == "Manage Subscriptions" ){
 
@@ -722,7 +722,7 @@ void playlistdownloader::plSubscription()
 
 						ss.emplace_back( e ) ;
 
-						m_parent.getListing( ss.move(),engine ) ;
+						m_parent.getListing( ss.move(),engine,false ) ;
 
 						return true ;
 					}else{
@@ -758,7 +758,7 @@ void playlistdownloader::download( const engines::engine& engine )
 	{
 	public:
 		meaw( playlistdownloader& parent,const engines::engine& engine ) :
-		    m_parent( parent ),m_engine( engine )
+			m_parent( parent ),m_engine( engine )
 		{
 		}
 		void operator()()
@@ -787,9 +787,6 @@ void playlistdownloader::download( const engines::engine& engine )
 		const engines::engine& m_engine ;
 	} ;
 
-	m_topDownloadingIndex = 0 ;
-	m_recursiveDownloading = 0 ;
-
 	m_ctx.logger().clear() ;
 
 	m_ctx.logger().setMaxProcessLog( m_table.rowCount() ) ;
@@ -799,22 +796,17 @@ void playlistdownloader::download( const engines::engine& engine )
 	engine.updateVersionInfo( m_ctx,meaw( *this,engine ) ) ;
 }
 
-void playlistdownloader::downloadRecursively( const engines::engine& eng,int index,bool recurse )
+void playlistdownloader::downloadRecursively( const engines::engine& eng,int index,bool downloadRecursively )
 {	
 	class events
 	{
 	public:
-		events( playlistdownloader& p,const engines::engine& engine,int index,bool recurse ) :
+		events( playlistdownloader& p,const engines::engine& engine,int index,bool dr ) :
 			m_parent( p ),
 			m_engine( engine ),
 			m_index( index ),
-			m_recurse( recurse )
+			m_downloadRecursively( dr )
 		{
-			if( m_recurse ){
-
-				m_parent.m_topDownloadingIndex++ ;
-				m_parent.m_recursiveDownloading++ ;
-			}
 		}
 		bool addData( const QByteArray& e )
 		{
@@ -844,23 +836,16 @@ void playlistdownloader::downloadRecursively( const engines::engine& eng,int ind
 				m = reportFinished::finishedStatus::state::done ;
 			}
 
-			if( m_recurse ){
+			if( m_downloadRecursively && !st.cancelled() ){
 
-				m_parent.m_recursiveDownloading-- ;
-
-				if( !st.cancelled() ){
-
-					this->startNext() ;
-				}
+				this->startNext() ;
 			}
 
 			reportFinished::finishedStatus s{ m_index,m,st } ;
 
 			emit m_parent.reportFinishedStatusSignal( { m_engine,s.move() },fileNames ) ;
 
-			auto a = m_engine.canShowMetaData() ;
-
-			if( fileNames.size() && a && st.success() && !m_engine.likeYtDlp() ){
+			if( fileNames.size() && st.success() && m_engine.isGalleryDl() ){
 
 				m_parent.setThumbnail( fileNames,m_engine,m_index ) ;
 			}
@@ -889,29 +874,17 @@ void playlistdownloader::downloadRecursively( const engines::engine& eng,int ind
 	private:
 		void startNext()
 		{
-			auto m = m_parent.m_topDownloadingIndex ;
+			auto m = m_parent.m_table.nextAvailableEntryToDownload( m_index + 1 ) ;
 
-			if( m < m_parent.m_table.rowCount() ){
+			if( m != -1 ){
 
-				auto e = m_parent.m_table.runningState( m ) ;
-
-				auto a = reportFinished::finishedStatus::running( e ) ;
-				auto b = reportFinished::finishedStatus::finishedWithSuccess( e ) ;
-
-				if( a || b ){
-
-					m_parent.m_topDownloadingIndex++ ;
-
-					this->startNext() ;
-				}else{
-					m_parent.downloadRecursively( m_engine,m,m_recurse ) ;
-				}
+				m_parent.downloadRecursively( m_engine,m,m_downloadRecursively ) ;
 			}
 		}
 		playlistdownloader& m_parent ;
 		const engines::engine& m_engine ;
 		int m_index ;
-		bool m_recurse ;
+		bool m_downloadRecursively ;
 	} ;
 
 	auto m = m_ui.lineEditPLUrlOptions->text() ;
@@ -932,7 +905,7 @@ void playlistdownloader::downloadRecursively( const engines::engine& eng,int ind
 	auto ff     = engine.filter( id ) ;
 	auto logger = make_loggerBatchDownloader( ff.move(),m_ctx.logger(),updater,error,id,logs ) ;
 
-	m_table.setRunningState( reportFinished::finishedStatus::running(),index ) ;
+	m_table.setStateAsRunning( index,downloadRecursively ) ;
 
 	auto optsUpdater = [ this ]( QStringList opts ){
 
@@ -959,7 +932,7 @@ void playlistdownloader::downloadRecursively( const engines::engine& eng,int ind
 			  m_ctx,
 			  { dopt,{ index,m_table.rowCount() },true,ent },
 			  m_terminator.setUp(),
-			  events( *this,engine,index,recurse ),
+			  events( *this,engine,index,downloadRecursively ),
 			  logger.move() ) ;
 }
 
@@ -986,7 +959,9 @@ void playlistdownloader::showBanner()
 	this->disableAll() ;
 }
 
-void playlistdownloader::getListing( playlistdownloader::listIterator e,const engines::engine& engine )
+void playlistdownloader::getListing( playlistdownloader::listIterator e,
+				    const engines::engine& engine,
+				    bool autoDownload )
 {
 	this->resizeTable( playlistdownloader::size::large ) ;
 
@@ -996,30 +971,31 @@ void playlistdownloader::getListing( playlistdownloader::listIterator e,const en
 	{
 	public:
 		meaw( playlistdownloader& p,
-			playlistdownloader::listIterator it,
-			const engines::engine& engine ) :
-			m_parent( p ),m_it( it.move() ),m_engine( engine )
+		      playlistdownloader::listIterator it,
+		      const engines::engine& engine,
+		      bool autoDownload  ) :
+			m_parent( p ),m_it( it.move() ),m_engine( engine ),m_autoDownload( autoDownload )
 		{
 		}
 		void operator()()
 		{
-			m_parent.getList( m_it.move(),m_engine ) ;
+			m_parent.getList( m_it.move(),m_engine,m_autoDownload ) ;
 		}
 	private:
 		playlistdownloader& m_parent ;
 		playlistdownloader::listIterator m_it ;
 		const engines::engine& m_engine ;
+		bool m_autoDownload ;
 	} ;
 
-	engine.updateVersionInfo( m_ctx,meaw( *this,e.move(),engine ) ) ;
+	engine.updateVersionInfo( m_ctx,meaw( *this,e.move(),engine,autoDownload ) ) ;
 }
 
 void playlistdownloader::getList( playlistdownloader::listIterator iter,
-				  const engines::engine& engine )
+				 const engines::engine& engine,
+				 bool autoDownload )
 {
-	m_dataReceived = false ;
 	m_stoppedOnExisting = false ;
-	m_downloaderId++ ;
 
 	auto url = iter.url() ;
 
@@ -1071,12 +1047,14 @@ void playlistdownloader::getList( playlistdownloader::listIterator iter,
 			const engines::engine& engine,
 			QStringList opts,
 			playlistdownloader& parent,
-			playlistdownloader::listIterator iter ) :
+			playlistdownloader::listIterator iter,
+			bool ad ) :
 			m_engine( engine ),
 			m_opts( std::move( opts ) ),
 			m_parent( parent ),
 			m_iter( std::move( iter ) ),
-			m_url( url )
+			m_url( url ),
+			m_autoDownload( ad )
 		{
 		}
 		customOptions bg()
@@ -1087,7 +1065,7 @@ void playlistdownloader::getList( playlistdownloader::listIterator iter,
 		}
 		void fg( customOptions o )
 		{
-			m_parent.getList( m_url,o.move(),m_engine,m_iter.move() ) ;
+			m_parent.getList( m_url,o.move(),m_engine,m_iter.move(),m_autoDownload ) ;
 		}
 	private:
 		const engines::engine& m_engine ;
@@ -1095,23 +1073,26 @@ void playlistdownloader::getList( playlistdownloader::listIterator iter,
 		playlistdownloader& m_parent ;
 		playlistdownloader::listIterator m_iter ;
 		QString m_url ;
+		bool m_autoDownload ;
 	} ;
 
-	utils::qthread::run( meaw( url,engine,std::move( opts ),*this,iter.move() ) ) ;
+	utils::qthread::run( meaw( url,engine,std::move( opts ),*this,iter.move(),autoDownload ) ) ;
 }
 
 void playlistdownloader::getList(  const QString& url,
 				  customOptions&& c,
 				  const engines::engine& engine,
-				  playlistdownloader::listIterator iter )
+				  playlistdownloader::listIterator iter,
+				  bool autoDownload )
 {
 	class events
 	{
 	public:
 		events( playlistdownloader& p,
 			const engines::engine& e,
-			playlistdownloader::listIterator i ) :
-			m_parent( p ),m_engine( e ),m_iter( i.move() )
+			playlistdownloader::listIterator i,
+			bool ad ) :
+			m_parent( p ),m_engine( e ),m_iter( i.move() ),m_autoDownload( ad )
 		{
 		}
 		const engines::engine& engine()
@@ -1128,7 +1109,7 @@ void playlistdownloader::getList(  const QString& url,
 
 				if( m_parent.m_stoppedOnExisting && m_iter.hasNext() ){
 
-					m_parent.getList( m_iter.next(),m_engine ) ;
+					m_parent.getList( m_iter.next(),m_engine,m_autoDownload ) ;
 				}else{
 					m_parent.enableAll() ;
 					m_parent.m_gettingPlaylist = false ;
@@ -1137,9 +1118,9 @@ void playlistdownloader::getList(  const QString& url,
 
 			}else if( m_iter.hasNext() ){
 
-				m_parent.getList( m_iter.next(),m_engine ) ;
+				m_parent.getList( m_iter.next(),m_engine,m_autoDownload ) ;
 			}else{
-				if( m_parent.m_autoDownload ){
+				if( m_autoDownload ){
 
 					m_parent.download() ;
 				}else{
@@ -1176,6 +1157,7 @@ void playlistdownloader::getList(  const QString& url,
 		playlistdownloader& m_parent ;
 		const engines::engine& m_engine ;
 		playlistdownloader::listIterator m_iter ;
+		bool m_autoDownload ;
 	} ;
 
 	auto opts = c.options() ;
@@ -1183,7 +1165,7 @@ void playlistdownloader::getList(  const QString& url,
 	stdOut sOut( *this,c.move(),engine,url ) ;
 	stdError sErr( *this,m_banner ) ;
 
-	events ev( *this,engine,iter.move() ) ;
+	events ev( *this,engine,iter.move(),autoDownload ) ;
 
 	auto& ll = m_ctx.logger() ;
 
@@ -1227,7 +1209,6 @@ bool playlistdownloader::enabled()
 
 bool playlistdownloader::parseJson( const engines::engine& engine,
 				   const customOptions& copts,
-				   tableWidget& table,
 				   utility::MediaEntry media )
 {
 	if( copts.contains( media.id() ) ){
@@ -1241,7 +1222,7 @@ bool playlistdownloader::parseJson( const engines::engine& engine,
 
 			auto mm = QObject::tr( "Stopping Because Media Is Already In Archive File" ) ;
 
-			this->showEntry( table,{ m_defaultVideoThumbnailIcon,s,media,mm } ) ;
+			this->showEntry( { m_defaultVideoThumbnailIcon,s,media,mm },false ) ;
 
 			return true ;
 
@@ -1251,7 +1232,7 @@ bool playlistdownloader::parseJson( const engines::engine& engine,
 
 			auto mm = QObject::tr( "Media Already In Archive" ) ;
 
-			this->showEntry( table,{ m_defaultVideoThumbnailIcon,s,media,mm } ) ;
+			this->showEntry( { m_defaultVideoThumbnailIcon,s,media,mm },false ) ;
 
 			return false ;
 		}
@@ -1279,40 +1260,23 @@ bool playlistdownloader::parseJson( const engines::engine& engine,
 
 		m_networkRunning++ ;
 
-		networkCtx m{ media.move(),m_downloaderId,table } ;
+		auto ua = engine.isGalleryDl() ? network.defaultUserAgent() : QByteArray() ;
 
-		auto ua = engine.likeYtDlp() ? QByteArray() : network.defaultUserAgent() ;
-
-		network.get( thumbnailUrl,m.move(),this,&playlistdownloader::networkResult,ua ) ;
+		network.get( thumbnailUrl,media.move(),this,&playlistdownloader::networkResult,ua ) ;
 	}else{
-		auto m = &playlistdownloader::networkData ;
-		utility::networkReply( this,m,&table,m_downloaderId,media.move() ) ;
+		emit this->networkDataSignal( { -1,media.move() } ) ;
 	}
 
 	return false ;
 }
 
-void playlistdownloader::networkResult( networkCtx d,const utils::network::reply& reply )
+void playlistdownloader::networkResult( utility::MediaEntry media,const utils::network::reply& reply )
 {
-	auto m = &playlistdownloader::networkData ;
-
-	utility::networkReply( this,m,m_ctx,reply,&d.table,d.id,d.media.move() ) ;
+	emit this->networkDataSignal( { m_ctx,reply,-1,media.move() } ) ;
 }
 
-void playlistdownloader::networkData( const utility::networkReply& m )
+void playlistdownloader::networkData( utility::networkReply m )
 {
-	if( m.id() < m_downloaderId ){
-
-		/*
-		 * Network responce took too long and we are now running
-		 * a newer request to get playlist entries
-		 */
-		//return ;
-	}
-
-	auto& table = m.table() ;
-	auto& media = m.media() ;
-
 	auto s = reportFinished::finishedStatus::notStarted() ;
 
 	if( networkAccess::hasNetworkSupport() ){
@@ -1326,16 +1290,16 @@ void playlistdownloader::networkData( const utility::networkReply& m )
 
 			auto img = pixmap.scaled( width,height ) ;
 
-			this->showEntry( table,{ img,s,media } ) ;
+			this->showEntry( { img,s,m.media() },true ) ;
 		}else{
 			const auto& img = m_defaultVideoThumbnailIcon ;
 
-			this->showEntry( table,{ img,s,media } ) ;
+			this->showEntry( { img,s,m.media() },true ) ;
 		}
 	}else{
 		const auto& img = m_defaultVideoThumbnailIcon ;
 
-		this->showEntry( table,{ img,s,media } ) ;
+		this->showEntry( { img,s,m.media() },true ) ;
 	}
 
 	m_networkRunning-- ;
@@ -1368,6 +1332,10 @@ void playlistdownloader::setThumbnail( const std::vector< QByteArray >& fileName
 		{
 			m_filePath = e ;
 		}
+		bool invalidEntry( const QByteArray& e ) const
+		{
+			return utility::fileIsInvalidForGettingThumbnail( e ) ;
+		}
 		QPixmap bg()
 		{
 			QFile f( m_filePath ) ;
@@ -1510,21 +1478,23 @@ void playlistdownloader::resizeTable( playlistdownloader::size s )
 	}
 }
 
-void playlistdownloader::showEntry( tableWidget& table,tableWidget::entry e )
+void playlistdownloader::showEntry( tableWidget::entry e,bool downloadable )
 {
-	auto row = table.addItem( e.move() ) ;
+	auto row = m_table.addItem( e.move() ) ;
 
 	m_ctx.logger().setMaxProcessLog( m_table.rowCount() ) ;
 
-	m_ctx.TabManager().Configure().setDownloadOptions( row,table ) ;
+	m_ctx.TabManager().Configure().setDownloadOptions( row,m_table ) ;
 
-	table.selectRow( row ) ;
+	m_table.selectRow( row ) ;
 
-	if( !m_ui.pbPLCancel->isEnabled() ){
+	if( !m_ui.pbPLCancel->isEnabled() && downloadable ){
 
 		auto e = static_cast< int >( m_settings.maxConcurrentDownloads() ) ;
 
-		if( m_recursiveDownloading > 0 && m_recursiveDownloading < e ){
+		auto m = m_table.totalRunningRecursively() ;
+
+		if( m > 0 && m < e ){
 
 			const auto& eng = this->defaultEngine() ;
 
@@ -1533,10 +1503,6 @@ void playlistdownloader::showEntry( tableWidget& table,tableWidget::entry e )
 			const auto& engine = utility::resolveEngine( m_table,eng,engines,row ) ;
 
 			this->downloadRecursively( engine,row,true ) ;
-
-		}else if( m_autoDownload ){
-
-			this->download() ;
 		}
 	}
 }
@@ -1760,13 +1726,11 @@ bool playlistdownloader::stdError::operator()( const QByteArray& e )
 	return e.startsWith( "WARNING" ) ;
 }
 
-void playlistdownloader::stdOut::operator()( tableWidget& table,Logger::Data& data )
+void playlistdownloader::stdOut::operator()( Logger::Data& data )
 {
-	m_parent.m_dataReceived = true ;
-
 	if( m_engine.likeYtDlp() ){
 
-		this->parseYtDlpData( table,data ) ;
+		this->parseYtDlpData( data ) ;
 	}else{
 		auto m = data.toLine() ;
 
@@ -1790,13 +1754,13 @@ void playlistdownloader::stdOut::operator()( tableWidget& table,Logger::Data& da
 
 				const auto mm = m_engine.parseJson( m_url,it ) ;
 
-				m_parent.parseJson( m_engine,m_customOptions,table,QJsonDocument( mm ) ) ;
+				m_parent.parseJson( m_engine,m_customOptions,QJsonDocument( mm ) ) ;
 			}
 		}
 	}
 }
 
-void playlistdownloader::stdOut::parseYtDlpData( tableWidget& table,Logger::Data& data )
+void playlistdownloader::stdOut::parseYtDlpData( Logger::Data& data )
 {
 	int position = 0 ;
 
@@ -1827,7 +1791,7 @@ void playlistdownloader::stdOut::parseYtDlpData( tableWidget& table,Logger::Data
 						media.setShowFirst() ;
 					}
 
-					if( m_parent.parseJson( m_engine,p,table,media.move() ) ){
+					if( m_parent.parseJson( m_engine,p,media.move() ) ){
 
 						break ;
 					}
