@@ -188,7 +188,7 @@ bool settings::useInternalArchiveFile()
 
 bool settings::enableLibraryTab()
 {
-	return this->getOption( "EnableLibraryTab",false ) ;
+	return this->getOption( "EnableLibraryTab",true ) ;
 }
 
 bool settings::printMediaPlayers()
@@ -228,7 +228,7 @@ void settings::setCookieSourceSetToBrowerName( bool e )
 
 qint64 settings::timeOutWaitingForClipboardData()
 {
-	return this->getOption( "TimeOutWaitingForClipboardData",30000 ) ;
+	return this->getOption( "TimeOutWaitingForClipboardData",5000 ) ;
 }
 
 void settings::setAutoHideDownloadWhenCompleted( bool e )
