@@ -624,8 +624,135 @@ std::vector< utility::PlayerOpts > utility::getMediaPlayers()
 	return a ;
 }
 
+#if QT_VERSION >= QT_VERSION_CHECK( 6,6,0 )
+
+void utility::checkPermissions::enable()
+{
+}
+
+void utility::checkPermissions::disable()
+{
+}
+
 #else
 
+extern Q_CORE_EXPORT int qt_ntfs_permission_lookup ;
+
+void utility::checkPermissions::enable()
+{
+	qt_ntfs_permission_lookup++ ;
+}
+
+void utility::checkPermissions::disable()
+{
+	qt_ntfs_permission_lookup-- ;
+}
+
+#endif
+
+QString windowsGetLastErrorMessage()
+{
+	char * s = nullptr ;
+
+	auto a = FORMAT_MESSAGE_FROM_SYSTEM ;
+	auto b = FORMAT_MESSAGE_IGNORE_INSERTS ;
+	auto c = FORMAT_MESSAGE_ALLOCATE_BUFFER ;
+
+	auto flags = a | b | c ;
+
+	auto le = GetLastError() ;
+	auto lg = MAKELANGID( LANG_NEUTRAL,SUBLANG_DEFAULT ) ;
+
+	FormatMessageA( flags,nullptr,le,lg,reinterpret_cast< char * >( &s ),0,nullptr ) ;
+
+	QString m = s ;
+
+	LocalFree( s ) ;
+
+	return m ;
+}
+
+class renameFile
+{
+public:
+	renameFile( const QString& oldPath,const QString& newPath ) :
+		m_oldPath( this->setPath( oldPath ) ),m_newPath( this->setPath( newPath ) )
+	{
+	}
+	bool exec() const
+	{
+		auto oldp = m_oldPath.toStdWString() ;
+		auto newp = m_newPath.toStdWString() ;
+
+		return MoveFileW( oldp.data(),newp.data() ) ;
+	}
+	QString errorString() const
+	{
+		return windowsGetLastErrorMessage() ;
+	}
+	const QString& oldPath() const
+	{
+		return m_oldPath ;
+	}
+	const QString& newPath() const
+	{
+		return m_newPath ;
+	}
+private:
+	QString setPath( const QString& e )
+	{
+		return QDir::toNativeSeparators( e ) ;
+	}
+	QString m_oldPath ;
+	QString m_newPath ;
+} ;
+
+#else
+
+QString windowsGetLastErrorMessage()
+{
+	return {} ;
+}
+
+void utility::checkPermissions::enable()
+{
+}
+
+void utility::checkPermissions::disable()
+{
+}
+
+class renameFile
+{
+public:
+	renameFile( const QString& oldPath,const QString& newPath ) :
+		m_oldPath( oldPath ),m_newPath( newPath )
+	{
+	}
+	bool exec() const
+	{
+		auto oldPath = m_oldPath.toUtf8() ;
+		auto newPath = m_newPath.toUtf8() ;
+
+		return rename( oldPath.constData(),newPath.constData() ) == 0 ;
+	}
+	QString errorString() const
+	{
+		return strerror( errno ) ;
+	}
+	const QString& oldPath() const
+	{
+		return m_oldPath ;
+	}
+	const QString& newPath() const
+	{
+		return m_newPath ;
+	}
+private:
+	QString m_oldPath ;
+	QString m_newPath ;
+} ;
+
 std::vector< utility::PlayerOpts > utility::getMediaPlayers()
 {
 	std::vector< utility::PlayerOpts > m ;
@@ -699,46 +826,6 @@ QString utility::windowsGateWayAddress()
 
 #endif
 
-#ifdef Q_OS_WIN
-
-#if QT_VERSION >= QT_VERSION_CHECK( 6,6,0 )
-
-void utility::checkPermissions::enable()
-{
-}
-
-void utility::checkPermissions::disable()
-{
-}
-
-#else
-
-extern Q_CORE_EXPORT int qt_ntfs_permission_lookup ;
-
-void utility::checkPermissions::enable()
-{
-	qt_ntfs_permission_lookup++ ;
-}
-
-void utility::checkPermissions::disable()
-{
-	qt_ntfs_permission_lookup-- ;
-}
-
-#endif
-
-#else
-
-void utility::checkPermissions::enable()
-{
-}
-
-void utility::checkPermissions::disable()
-{
-}
-
-#endif
-
 utility::debug& utility::debug::operator<<( const QString& e )
 {
 	return _print( e.toStdString().c_str() ) ;
@@ -787,34 +874,6 @@ utility::debug& utility::debug::operator<<( const QByteArray& e )
 	return _print( e.data() ) ;
 }
 
-static void _kill_children_recursively( const QString& id )
-{
-	auto path = QString( "/proc/%1/task/" ).arg( id ) ;
-
-	auto filter = QDir::Filter::Dirs | QDir::Filter::NoDotAndDotDot ;
-
-	const auto ff = QDir( path ).entryList( filter ) ;
-
-	for( const auto& it : ff ){
-
-		QFile file( path + it + "/children" ) ;
-
-		if( file.open( QIODevice::ReadOnly ) ){
-
-			const auto pids = util::split( file.readAll(),' ',true ) ;
-
-			for( const auto& it : pids ){
-
-				_kill_children_recursively( it ) ;
-
-				QProcess exe ;
-				exe.start( "kill",{ "-s","SIGTERM",it } ) ;
-				exe.waitForFinished( -1 ) ;
-			}
-		}
-	}
-}
-
 bool utility::Terminator::terminate( QProcess& exe )
 {
 	if( utility::platformIsWindows() ){
@@ -836,15 +895,40 @@ bool utility::Terminator::terminate( QProcess& exe )
 			}
 			void bg()
 			{
-				auto m = QString::number( m_exe.processId() ) ;
-
-				_kill_children_recursively( m ) ;
+				this->terminate( QString::number( m_exe.processId() ) ) ;
 			}
 			void fg()
 			{
 				m_exe.terminate() ;
 			}
 		private:
+			void terminate( const QString& id )
+			{
+				auto path = QString( "/proc/%1/task/" ).arg( id ) ;
+
+				auto filter = QDir::Filter::Dirs | QDir::Filter::NoDotAndDotDot ;
+
+				const auto ff = QDir( path ).entryList( filter ) ;
+
+				for( const auto& it : ff ){
+
+					QFile file( path + it + "/children" ) ;
+
+					if( file.open( QIODevice::ReadOnly ) ){
+
+						const auto pids = util::split( file.readAll(),' ',true ) ;
+
+						for( const auto& it : pids ){
+
+							this->terminate( it ) ;
+
+							QProcess exe ;
+							exe.start( "kill",{ "-s","SIGTERM",it } ) ;
+							exe.waitForFinished( -1 ) ;
+						}
+					}
+				}
+			}
 			QProcess& m_exe ;
 		} ;
 
@@ -1323,6 +1407,7 @@ void utility::saveDownloadList( const Context& ctx,QMenu& m,tableWidget& tableWi
 		}
 
 		auto s = QFileDialog::getSaveFileName( &ctx.mainWidget(),toolTip,filePath ) ;
+
 		if( !s.isEmpty() ){
 
 			const auto e = _saveDownloadList( tableWidget,false ) ;
@@ -1522,37 +1607,27 @@ bool utility::platformIs32Bit()
 
 void utility::addJsonCmd::add( const utility::addJsonCmd::entry& e )
 {
-	m_obj.insert( e.platform,[ & ]{
+	QJsonObject s ;
 
-		QJsonObject s ;
+	for( const auto& it : e.platformData ){
 
-		for( const auto& it : e.platformData ){
+		QJsonObject a ;
 
-			s.insert( it.archName,[ & ](){
+		a.insert( "Name",it.exeName ) ;
 
-				QJsonObject a ;
+		QJsonArray arr ;
 
-				a.insert( "Name",it.exeName ) ;
+		for( const auto& xt : it.exeArgs ){
 
-				a.insert( "Args",[ & ](){
-
-					QJsonArray arr ;
-
-					for( const auto& xt : it.exeArgs ){
-
-						arr.append( xt ) ;
-					}
-
-					return arr ;
-				}() ) ;
-
-				return a ;
-			}() ) ;
+			arr.append( xt ) ;
 		}
 
-		return s ;
+		a.insert( "Args",arr ) ;
 
-	}() ) ;
+		s.insert( it.archName,a ) ;
+	}
+
+	m_obj.insert( e.platform,s ) ;
 }
 
 QString utility::fromSecsSinceEpoch( qint64 s )
@@ -2053,7 +2128,7 @@ void utility::networkReply::getData( const Context& ctx,const utils::network::re
 
 		ctx.logger().add( m,utility::concurrentID() ) ;
 	}else{
-		ctx.logger().add( "Network Error:\n" + reply.errorString(),utility::concurrentID() ) ;
+		ctx.logger().add( "Network Error: " + reply.errorString(),utility::concurrentID() ) ;
 	}
 }
 
@@ -2604,15 +2679,30 @@ quint64 utility::simpleRandomNumber()
 	return static_cast< quint64 >( time( nullptr ) ) ;
 }
 
-QString utility::rename( QTableWidgetItem& item,
-			 const QString& cwd,
-			 const QString& newName,
-			 const QString& oldName )
+QString utility::rename( const Context& ctx,
+			QTableWidgetItem& item,
+			const QString& cwd,
+			const QString& newName,
+			const QString& oldName )
 {
+	Logger& logger = ctx.logger() ;
+
 	auto oldPath = cwd + "/" + oldName ;
 	auto newPath = cwd + "/" + newName ;
 
-	if( QDir().rename( oldPath,newPath ) ){
+	auto id = utility::concurrentID() ;
+
+	renameFile rename( oldPath,newPath ) ;
+
+	auto e = QObject::tr( "Renaming \"%1\" to \"%2\"" ) ;
+
+	auto bar = utility::barLine() ;
+
+	logger.add( bar,id ) ;
+
+	logger.add( e.arg( rename.oldPath(),rename.newPath() ),id ) ;
+
+	if( rename.exec() ){
 
 		auto txt = item.text() ;
 
@@ -2620,8 +2710,16 @@ QString utility::rename( QTableWidgetItem& item,
 
 		item.setText( txt ) ;
 
+		logger.add( bar,id ) ;
+
 		return newName ;
 	}else{
+		auto s = rename.errorString() ;
+
+		ctx.logger().add( QObject::tr( "Renaming Failed: %3" ).arg( s ),id ) ;
+
+		logger.add( bar,id ) ;
+
 		return {} ;
 	}
 }
@@ -2652,3 +2750,8 @@ void utility::copyToClipboardUrls( tableWidget& table )
 		m->setText( list.join( "\n" ) ) ;
 	}
 }
+
+bool utility::fileIsInvalidForGettingThumbnail( const QByteArray& e )
+{
+	return e.endsWith( ".mp4" ) || e.endsWith( ".webm" ) || e.endsWith( ".avi" ) ;
+}
