@@ -579,18 +579,20 @@ namespace utility
 	bool platformisFlatPak() ;
 	bool addData( const QByteArray& ) ;
 	bool containsLinkerWarning( const QByteArray& ) ;
-	QString rename( QTableWidgetItem&,const QString&,const QString&,const QString& ) ;
+	QString rename( const Context&,QTableWidgetItem&,const QString&,const QString&,const QString& ) ;
 	void deleteTmpFiles( const QString&,std::vector< QByteArray > ) ;
 	QString OSXApplicationDirPath() ;
 	QString OSXtranslationFilesPath() ;
 	QString OSX3rdPartyDirPath() ;
 	QString windowsApplicationDirPath() ;
 	QString windowsGateWayAddress() ;
+	QString windowsGetLastErrorMessage() ;
 	QString windowsGetClipBoardText( const ContextWinId& ) ;
 	void windowsSetDarkModeTitleBar( const Context& ) ;	
 	QByteArray barLine() ;
 	void copyToClipboardUrls( tableWidget& ) ;
 	bool isRelativePath( const QString& ) ;
+	bool fileIsInvalidForGettingThumbnail( const QByteArray& ) ;
 	QString downloadFolder( const Context& ctx ) ;
 	bool onlyWantedVersionInfo( const utility::cliArguments& ) ;
 	bool startedUpdatedVersion( settings&,const utility::cliArguments& ) ;
@@ -610,7 +612,7 @@ namespace utility
 
 		for( const auto& it : fileNames ){
 
-			if( it.endsWith( ".mp4" ) || it.endsWith( ".webm" ) || it.endsWith( ".avi" ) ){
+			if( parent.invalidEntry( it ) ){
 
 				continue ;
 			}else{
@@ -1744,30 +1746,6 @@ namespace utility
 		bool m_showFirst = false ;
 	} ;
 
-	class networkReply ;
-
-	class networkReplyInvoker : public QObject
-	{
-		Q_OBJECT
-	public:
-		template< typename Object,typename Member >
-		networkReplyInvoker( Object obj,Member member,const networkReply& nr )
-		{
-			connect( this,
-				 &networkReplyInvoker::send,
-				 obj,
-				 member,
-				 Qt::QueuedConnection ) ;
-
-			emit send( nr ) ;
-
-			this->deleteLater() ;
-		}
-	private:
-	signals:
-		void send( const networkReply& ) ;
-	} ;
-
 	class networkReply
 	{
 	public:
@@ -1778,33 +1756,19 @@ namespace utility
 		{
 			this->getData( ctx,reply ) ;
 		}
-		template< typename Object,typename Member >
-		networkReply( Object obj,
-			      Member member,
-			      tableWidget * t,
-			      int id,
-			      utility::MediaEntry m ) :
+		networkReply( int id,utility::MediaEntry m ) :
 			m_id( id ),
-			m_mediaEntry( m.move() ),
-			m_table( t )
+			m_mediaEntry( m.move() )
 		{
-			new utility::networkReplyInvoker( obj,member,*this ) ;
 		}
-		template< typename Object,typename Member >
-		networkReply( Object obj,
-			      Member member,
-			      const Context& ctx,
+		networkReply( const Context& ctx,
 			      const utils::network::reply& reply,
-			      tableWidget * t,
 			      int id,
 			      utility::MediaEntry m ) :
 			m_id( id ),
-			m_mediaEntry( m.move() ),
-			m_table( t )
+			m_mediaEntry( m.move() )
 		{
 			this->getData( ctx,reply ) ;
-
-			new utility::networkReplyInvoker( obj,member,*this ) ;
 		}
 		const QByteArray& data() const
 		{
@@ -1814,10 +1778,6 @@ namespace utility
 		{
 			return !m_data.isEmpty() ;
 		}
-		int id() const
-		{
-			return m_id ;
-		}
 		int index() const
 		{
 			return m_id ;
@@ -1826,16 +1786,11 @@ namespace utility
 		{
 			return m_mediaEntry ;
 		}
-		tableWidget& table() const
-		{
-			return *m_table ;
-		}
 	private:
 		void getData( const Context& ctx,const utils::network::reply& ) ;
 		QByteArray m_data ;
 		int m_id ;
 		utility::MediaEntry m_mediaEntry ;
-		tableWidget * m_table ;
 	};
 
 	template< typename FinishedState >
