@@ -1073,6 +1073,18 @@ Per maggiori dettagli vedi la GNU (General Public License).</translation>
         <source>Download Failed, Network Issue</source>
         <translation>Download fallito, problema di rete</translation>
     </message>
+    <message>
+        <source>Ukrainian (Ukraine)</source>
+        <translation>Ucraino (Ucraina)</translation>
+    </message>
+    <message>
+        <source>Renaming &quot;%1&quot; to &quot;%2&quot;</source>
+        <translation>Rinoma di &quot;%1&quot; in &quot;%2&quot;</translation>
+    </message>
+    <message>
+        <source>Renaming Failed: %3</source>
+        <translation>Rinomina fallita: %3</translation>
+    </message>
 </context>
 <context>
     <name>basicdownloader</name>
